<?php

namespace Controllers;

use Exception\CustomException;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;

class Password
{
    /** @var \Services\Password $passwordService */
    protected $passwordService;

    /**
     * @param \Services\Password $passwordService
     */
    public function __construct(\Services\Password $passwordService) {
        $this->passwordService = $passwordService;
    }

    /**
     * @param Request\Filter $request
     * @param Response $response
     */
    public function requestNewPassword(Request\Filter $request, Response $response) {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $email      = Utilities::getValueInFilterDataSourceByName($conditions, 'EMAIL');
            $style      = Utilities::getValueInFilterDataSourceByName($conditions, 'STYLE');
            $data = $this->passwordService->requestNewPassword($email, $style);
            $response->addDataSet(new DataSet ('requestNewPassword', [$data]));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }

    /**
     * @param Request\Filter $request
     * @param Response $response
     */
    public function updatePassword(Request\Filter $request, Response $response) {
        try {
            $conditions     = $request->getFilterCriteria()->getConditions();
            $actualPassword = Utilities::getValueInFilterDataSourceByName($conditions, 'ACTUAL_PASSWORD');
            $newPassword    = Utilities::getValueInFilterDataSourceByName($conditions, 'NEW_PASSWORD');
            $newPassConfirm = Utilities::getValueInFilterDataSourceByName($conditions, 'CONFIRM_NEW_PASSWORD');
            $email          = Utilities::getValueInFilterDataSourceByName($conditions, 'EMAIL');
            $this->passwordService->updatePassword($actualPassword, $newPassword, $newPassConfirm, $email);
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
} 